@@ -128,7 +128,7 @@ tvp_git_action_class_init (TvpGitActionClass *klass)
     action_signal[SIGNAL_NEW_PROCESS] = g_signal_new("new-process", G_OBJECT_CLASS_TYPE(gobject_class), G_SIGNAL_RUN_FIRST,
             0, NULL, NULL, tsh_cclosure_marshal_VOID__POINTER_STRING, G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_STRING);
 
-    tvp_action_arg_quark = g_quark_from_static_string ("tvp-action-arg");
+    tvp_action_arg_quark = g_quark_from_string ("tvp-action-arg");
 }
 
 
@@ -364,7 +364,7 @@ static void tvp_action_exec (GtkAction *item, TvpGitAction *tvp_action)
                 file = g_strdup (file);
 
                 /* remove trailing '/' cause git can't handle that */
-                if (file[strlen (file) - 1] == '/')
+                if (strlen (file) > 1 && file[strlen (file) - 1] == '/')
                 {
                     file[strlen (file) - 1] = '\0';
                 }
