@@ -1,20 +1,19 @@
 /*-
- * Copyright (c) 2006 Peter de Ridder <peter@xfce.org>
+ * Copyright (C) 2007-2011  Peter de Ridder <peter@xfce.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -326,13 +325,13 @@ tvp_compare_filename (const gchar *uri1, const gchar *uri2)
   path2 = g_strdup (uri2);
 
   /* remove trailing '/' */
-  if (path1[strlen (path1) - 1] == '/')
+  if (strlen (path1) > 1 && path1[strlen (path1) - 1] == '/')
   {
     path1[strlen (path1) - 1] = '\0';
   }
 
   /* remove trailing '/'*/
-  if (path2[strlen (path2) - 1] == '/')
+  if (strlen (path2) > 1 && path2[strlen (path2) - 1] == '/')
   {
     path2[strlen (path2) - 1] = '\0';
   }
