@@ -143,7 +143,7 @@ tvp_svn_action_class_init (TvpSvnActionClass *klass)
   action_signal[SIGNAL_NEW_PROCESS] = g_signal_new("new-process", G_OBJECT_CLASS_TYPE(gobject_class), G_SIGNAL_RUN_FIRST,
     0, NULL, NULL, tsh_cclosure_marshal_VOID__POINTER_STRING, G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_STRING);
 
-  tvp_action_arg_quark = g_quark_from_static_string ("tvp-action-arg");
+  tvp_action_arg_quark = g_quark_from_string ("tvp-action-arg");
 }
 
 
@@ -341,10 +341,10 @@ tvp_svn_action_create_menu_item (GtkAction *action)
   {
     add_subaction (action, GTK_MENU_SHELL (menu), "tvp::delete", Q_("Menu|Delete"), _("Delete"), GTK_STOCK_DELETE, "--delete");
   }
-  /* Version control (file) */
-  if (tvp_action->property.file_version_control) 
+  /* Version control (all) */
+  if ((tvp_action->property.is_parent && tvp_action->property.parent_version_control) || tvp_action->property.directory_version_control || tvp_action->property.file_version_control)
   {
-    add_subaction_u (GTK_MENU_SHELL (menu), "tvp::diff", Q_("Menu|Diff"), _("Diff"), GTK_STOCK_FIND_AND_REPLACE, _("Diff"));
+    add_subaction (action, GTK_MENU_SHELL (menu), "tvp::diff", Q_("Menu|Diff"), _("Diff"), GTK_STOCK_CONVERT, "--diff");
   }
   /* Version control and No version control (parent) */
   if (tvp_action->property.is_parent || tvp_action->property.directory_version_control || tvp_action->property.file_version_control)
@@ -517,7 +517,7 @@ static void tvp_action_exec (GtkAction *item, TvpSvnAction *tvp_action)
         file = g_strdup (file);
 
         /* remove trailing '/' cause svn can't handle that */
-        if (file[strlen (file) - 1] == '/')
+        if (strlen (file) > 1 && file[strlen (file) - 1] == '/')
         {
           file[strlen (file) - 1] = '\0';
         }
