@@ -94,7 +94,7 @@ tgh_status_dialog_init (TghStatusDialog *dialog)
   
   renderer = gtk_cell_renderer_toggle_new ();
   gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (tree_view),
-                                               -1, ("Commit"),
+                                               -1, _("Commit"),
                                                renderer, "active",
                                                COLUMN_ADDED, NULL);
 
@@ -106,7 +106,7 @@ tgh_status_dialog_init (TghStatusDialog *dialog)
   
   renderer = gtk_cell_renderer_text_new ();
   gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (tree_view),
-                                               -1, ("State"),
+                                               -1, _("State"),
                                                renderer, "text",
                                                COLUMN_STAT, NULL);
 
