@@ -29,6 +29,7 @@
 
 #include <libxfce4util/libxfce4util.h>
 
+#include <subversion-1/svn_version.h>
 #include <subversion-1/svn_client.h>
 #include <subversion-1/svn_pools.h>
 
@@ -49,20 +50,22 @@ struct thread_args {
 
 static gpointer delete_thread (gpointer user_data)
 {
-	struct thread_args *args = user_data;
-	svn_error_t *err;
-  svn_commit_info_t *commit_info;
+  struct thread_args *args = user_data;
+  svn_error_t *err;
   apr_array_header_t *paths;
-	svn_client_ctx_t *ctx = args->ctx;
-	apr_pool_t *subpool, *pool = args->pool;
-	TshNotifyDialog *dialog = args->dialog;
+  svn_client_ctx_t *ctx = args->ctx;
+  apr_pool_t *subpool, *pool = args->pool;
+  TshNotifyDialog *dialog = args->dialog;
   gchar **files = args->files;
   gint size, i;
   gchar *error_str;
+#if CHECK_SVN_VERSION_S(1,6)
+  svn_commit_info_t *commit_info;
   gchar *message;
   gchar buffer[256];
+#endif
 
-	g_free (args);
+  g_free (args);
 
   size = files?g_strv_length(files):0;
 
@@ -84,22 +87,27 @@ static gpointer delete_thread (gpointer user_data)
     APR_ARRAY_PUSH (paths, const char *) = ""; // current directory
   }
 
-	if ((err = svn_client_delete3(&commit_info, paths, FALSE, FALSE, NULL, ctx, subpool)))
-	{
+#if CHECK_SVN_VERSION_S(1,6)
+  if ((err = svn_client_delete3(&commit_info, paths, FALSE, FALSE, NULL, ctx, subpool)))
+#else /* CHECK_SVN_VERSION(1,7) */
+  if ((err = svn_client_delete4(paths, FALSE, FALSE, NULL, tsh_commit_func2, dialog, ctx, subpool)))
+#endif
+  {
     svn_pool_destroy (subpool);
 
     error_str = tsh_strerror(err);
-		gdk_threads_enter();
+    gdk_threads_enter();
     tsh_notify_dialog_add(dialog, _("Failed"), error_str, NULL);
-		tsh_notify_dialog_done (dialog);
-		gdk_threads_leave();
+    tsh_notify_dialog_done (dialog);
+    gdk_threads_leave();
     g_free(error_str);
 
-		svn_error_clear(err);
+    svn_error_clear(err);
     tsh_reset_cancel();
-		return GINT_TO_POINTER (FALSE);
-	}
+    return GINT_TO_POINTER (FALSE);
+  }
 
+#if CHECK_SVN_VERSION_S(1,6)
   if(commit_info && SVN_IS_VALID_REVNUM(commit_info->revision))
   {
     g_snprintf(buffer, 256, _("At revision: %ld"), commit_info->revision);
@@ -109,16 +117,19 @@ static gpointer delete_thread (gpointer user_data)
   {
     message = _("Local delete");
   }
+#endif
 
   svn_pool_destroy (subpool);
 
-	gdk_threads_enter();
+  gdk_threads_enter();
+#if CHECK_SVN_VERSION_S(1,6)
   tsh_notify_dialog_add(dialog, _("Completed"), message, NULL);
-	tsh_notify_dialog_done (dialog);
-	gdk_threads_leave();
-	
+#endif
+  tsh_notify_dialog_done (dialog);
+  gdk_threads_leave();
+
   tsh_reset_cancel();
-	return GINT_TO_POINTER (TRUE);
+  return GINT_TO_POINTER (TRUE);
 }
 
 GThread *tsh_delete (gchar **files, svn_client_ctx_t *ctx, apr_pool_t *pool)
